<?php
/**
 * @package    Proxim
 * @author     Davison Pro <davisonpro.coder@gmail.com | https://davisonpro.dev>
 * @copyright  2019 Proxim
 * @version    1.0.0
 * @since      File available since Release 1.0.0
 */

namespace Proxim;

class Payment extends ObjectModel {
    /** @var int $id Payment ID */
    public $id;

    /** @var int node_id */
    public $node_id;

    /** @var string node_type */
    public $node_type;

    /** @var int currency_id */
    public $currency_id;

    /** @var float conversion_rate */
    public $conversion_rate;

    /** @var string transaction_id */
    public $transaction_id;

    /** @var string payment_method */
    public $payment_method;

    /** @var float amount */
    public $amount;

    /** @var int date_add */
    public $date_add;

    /**
     * @see ObjectModel::$definition
     */
    public static $definition = array(
        'table' => 'payment',
        'primary' => 'payment_id',
        'fields' => array( 
            'node_id' => array('type' => self::TYPE_INT, 'validate' => 'isUnsignedId', 'required' => true),
            'node_type' => array('type' => self::TYPE_STRING, 'validate' => 'isAnything', 'size' => 20),
            'currency_id' => array('type' => self::TYPE_INT, 'validate' => 'isUnsignedId', 'required' => true),
            'conversion_rate' => array('type' => self::TYPE_FLOAT, 'validate' => 'isFloat'),
            'transaction_id' => array('type' => self::TYPE_STRING, 'validate' => 'isAnything', 'size' => 254),
            'payment_method' => array('type' => self::TYPE_STRING, 'validate' => 'isGenericName'),
            'amount' => array('type' => self::TYPE_FLOAT, 'validate' => 'isPrice', 'required' => true),
            'date_add' => array('type' => self::TYPE_DATE, 'validate' => 'isDate'),
        ),
    );
}