<?php 
/**
 * @package    Proxim
 * @author     Davison Pro <davis@davisonpro.dev | https://davisonpro.dev>
 * @copyright  2020 Proxim
 * @version    1.0
 * @since      File available since Release 1.0
*/

namespace Proxim\Presenter\Order;

use Proxim\Presenter\AbstractLazyArray;
use Doctrine\Common\Annotations\AnnotationException;
use Proxim\Application;
use Proxim\Order\Order;
use Proxim\Order\Rating;
use Proxim\Preference\AcademicLevel;
use Proxim\Preference\Discipline;
use Proxim\Preference\PaperType;
use Proxim\Util\DateUtils;
use Proxim\Validate;

class OrderRatingLazyArray extends AbstractLazyArray {
    /** @var Application */
    public $application;

    /** @var Order */
    public $order;

    /** @var Rating */
    public $rating;

    /**
     * OrderRatingArray constructor.
     *
     * @throws AnnotationException
     * @throws ReflectionException
     */
    public function __construct(Rating $rating)
    {
        $this->application = Application::getInstance();
        $this->rating = $rating;

        $order = new Order( (int) $rating->order_id );
        $this->order = $order;

        parent::__construct();
    }

    /**
     * @arrayAccess
     *
     * @return int
     */
    public function getId()
    {
        return (int) $this->rating->id;
    }

    /**
     * @arrayAccess
     *
     * @return int
     */
    public function getCustomerId()
    {
        return (int) $this->order->customer_id;
    }

    /**
     * @arrayAccess
     *
     * @return int
     */
    public function getOrderId()
    {
        return (int) $this->order->id;
    }

    /**
     * @arrayAccess
     *
     * @return int
     */
    public function getPaperRating()
    {
        return (int) $this->rating->paper_rating;
    }

    /**
     * @arrayAccess
     *
     * @return int
     */
    public function getServiceRating()
    {
        return (int) $this->rating->service_rating;
    }

    /**
     * @arrayAccess
     *
     * @return string
     */
    public function getBody()
    {
        return $this->rating->comment;
    }

    /**
     * @arrayAccess
     *
     * @return string
     */
    public function getOrderTopic()
    {
        return $this->order->title;
    }

    /**
     * @arrayAccess
     *
     * @return string
     */
    public function getAcademicLevel()
    {
        $academicLevel = new AcademicLevel((int) $this->order->academic_level_id);
        return $academicLevel->title;
    }

    /**
     * @arrayAccess
     *
     * @return string
     */
    public function getOrderDiscipline()
    {
        if($this->order->topic_category_option) {
            return $this->order->topic_category_option;
        }

        $discipline = new Discipline( (int) $this->order->topic_category_id);
        return (string) $discipline->title;
    }

    /**
     * @arrayAccess
     *
     * @return string
     */
    public function getPaperType()
    {
        $paperType = new PaperType( (int) $this->order->paper_type_id );
        if(Validate::isLoadedObject($paperType)) {
            return (string) $paperType->title;
        }

        return "Other";
    }

    /**
     * @arrayAccess
     *
     * @return int
     */
    public function getOrderPages()
    {
        return (int) $this->order->pages;
    }

    /**
     * @arrayAccess
     *
     * @return int
     */
    public function getOrderSlides()
    {
        return (int) $this->order->slides;
    }

    /**
     * @arrayAccess
     *
     * @return int
     */
    public function getOrderCharts()
    {
        return (int) $this->order->charts;
    }

    /**
     * @arrayAccess
     *
     * @return string
     */
    public function getCreatedAt() {
        return DateUtils::convertToISOFormat($this->order->date_add);
    }
}