<?php 
/**
 * @package    Proxim 
 * @author     Davison Pro <davisonpro.coder@gmail.com>
 * @copyright  2019 Proxim
 * @version    1.0.0
 * @since      File available since Release 1.0.0
 */

namespace Proxim\User;

use Db;
use Proxim\Database\DbQuery;
use Proxim\ObjectModel;

/**
 * Referral
 */
class Referral extends ObjectModel {
    /** @var $id Referral ID */
    public $id;

    /** @var int referrer_id */
    public $referrer_id;

    /** @var int referree_id */
    public $referree_id;

    /** @var string code */
    public $code;

    /** @var float amount */
    public $amount = 0;

    /** @var bool referrer_used */
    public $referrer_used = 0;

    /** @var float referree_used */
    public $referree_used = 0;

    /** @var string date_upd */
	public $date_upd;

	/** @var string date_add */
	public $date_add;
    
    /**
     * @see ObjectModel::$definition
     */
    public static $definition = array(
        'table' => 'referral',
        'primary' => 'referral_id',
        'fields' => array(
            'referrer_id' => array('type' => self::TYPE_INT, 'validate' => 'isUnsignedInt'),
            'referree_id' => array('type' => self::TYPE_INT, 'validate' => 'isUnsignedInt'),
			'code' => array('type' => self::TYPE_STRING, 'validate' => 'isGenericName', 'required' => true),
            'amount' => array('type' => self::TYPE_FLOAT, 'validate' => 'isPrice'),
            'referrer_used' => array('type' => self::TYPE_BOOL, 'validate' => 'isBool'),
            'referree_used' => array('type' => self::TYPE_BOOL, 'validate' => 'isBool'),
            'date_upd' => array('type' => self::TYPE_DATE, 'validate' => 'isDateOrNull'),
            'date_add' => array('type' => self::TYPE_DATE, 'validate' => 'isDate')
        )
    );

    /**
     * constructor.
     *
     * @param null $id
     */
    public function __construct($id = null)
    {
        parent::__construct($id);
    }

    /**
     * getReferees
     *
     * @param int $referrer_id 
     *
     * @return array Referees
     */
    public static function getReferees( $referrerId ) {
        $sql = new DbQuery();
        $sql->select('*');
        $sql->from('referral');
        $sql->where('referrer_id = ' . (int) $referrerId );
        $referees = Db::getInstance()->executeS($sql);

        return $referees;
    }

    public static function referralExists($referrer_id, $referree_id) {
        $referralExists = (bool) Db::getInstance()->getValue('SELECT referral_id FROM ' . Db::prefix('referral') . ' WHERE referrer_id = ' . (int) $referrer_id . ' AND referree_id = ' . (int) $referree_id );
        return $referralExists;
    }
}