<?php
use Proxim\Application;
use Proxim\Configuration;
use Proxim\Currency;
use Proxim\Module\Module;
use Proxim\Module\PaymentModule;
use Proxim\Order\AdditionalService;
use Proxim\Order\Order;
use Proxim\Site\Site;
use Proxim\Tools;
use Proxim\User\Customer;
use Proxim\Util\ArrayUtils;
use Proxim\Validate;

class ElivalatPay extends PaymentModule
{
    /**
    * ElivalatPay configuration
    */
    const ELIVALATPAY_ENABLED = 'ELIVALATPAY_ENABLED';
    const ELIVALATPAY_MODE = 'ELIVALATPAY_MODE';
    const ELIVALATPAY_MERCHANT_ID = 'ELIVALATPAY_MERCHANT_ID';
    const ELIVALATPAY_MERCHANT_LOGIN = 'ELIVALATPAY_MERCHANT_LOGIN';

    public function __construct()
    {
        $this->name = 'elivalatpay';
        $this->icon = 'fab fa-credit-card';
        $this->version = '1.0.0';
        $this->prox_versions_compliancy = array('min' => '1.0.0', 'max' => Application::VERSION);
        $this->author = 'Davison Pro';
        $this->displayName = 'Elivalat Pay';
        $this->description = 'Set up Elivalat Pay as a payment method and enable users to pay without leaving your website';

        $this->bootstrap = true;
        parent::__construct();
    }

    public function isActive() {
        return Configuration::get(self::ELIVALATPAY_ENABLED);
    }

    /**
     * Echoes a template.
     *
     * @param string $templateName Template name
     */
    public function showTemplate($templateName)
    {
        echo $this->getTemplateContent($templateName);
    }

    /**
     * Return a template.
     *
     * @param string $templateName          Template name
     * @param array  $additionnalParameters Additionnal parameters to inject on the Twig template
     *
     * @return string Parsed template
     */
    private function getTemplateContent($templateName, $additionnalParameters = array())
    {
        $this->smarty->assign($additionnalParameters);
        return $this->fetch(__DIR__ . '/views/' . $templateName.'.tpl');
    }

    function createXmlParameter(
        $order_id, 
        $amount, 
        $currency, 
        $email, 
        $firstname, 
        $lastname,
        $street, 
        $zip, 
        $city, 
        $state, 
        $country,
        $url_back_redirect_success,
        $url_back_redirect_failure, 
        $url_status_notification
    ) {
        $merchant_id = Configuration::get(self::ELIVALATPAY_MERCHANT_ID);
        $merchant_login = Configuration::get(self::ELIVALATPAY_MERCHANT_LOGIN);

        $xml='<?xml version="1.0" encoding="utf-8"?>';
        $xml .='<soap:Envelope xmlns:soap="http://schemas.xmlsoap.org/soap/envelope/"';     
        $xml .='   xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" ';     
        $xml .='  xmlns:xsd="http://www.w3.org/2001/XMLSchema">';
            $xml .='         <soap:Body>';
                $xml .=' <sspg_request xmlns="http://sspg.payment-processor.de">';
                $xml .=' <request_header>' ;
                $xml .='   <merchant_id>' .$merchant_id .'</merchant_id>' ;
                $xml .='   <merchant_login>'.$merchant_login.'</merchant_login>' ;
                $xml .='   <communication_id>1234567890</communication_id>' ;
                $xml .='   <application_id>MCHR</application_id>' ;
                $xml .='  <sspg_interface>' ;
                $xml .='    <interface>WGP</interface>' ;
                $xml .='    <version>1.0</version>' ;
                $xml .='    <request_type>AUTHORIZATION</request_type>' ;
                $xml .='    <response_type>SYNC</response_type>' ;
                $xml .='   </sspg_interface>' ;
                $xml .='  </request_header>' ;
                $xml .='  <request_data>' ;
                $xml .='  <transaction>' ;
                $xml .='    <order_id>'. $order_id.'</order_id>' ;
                $xml .='    <amount>'. $amount .'</amount>' ;
                $xml .='   <currency>'. $currency.'</currency>' ;
                $xml .='   <payment_method type="CC">' ;
                $xml .='     <payment_instrument type="credit_card">' ;
                $xml .='      <credit_card_data>' ;
                $xml .='      <cardholder_name>John Doe</cardholder_name>' ;
                $xml .='       <ccn>4242424242424242</ccn>' ;
                $xml .='       <brand>VISA</brand>' ;
                $xml .='     <exp_month>06</exp_month>' ;
                $xml .='       <exp_year>2021</exp_year>' ;
                $xml .='       <cvc>123</cvc>' ;
                $xml .='      </credit_card_data>' ;
                $xml .='    </payment_instrument>' ;
                $xml .='   </payment_method>' ;
                $xml .='    <customer>' ;
                $xml .='     <firstname>' .$firstname. '</firstname>' ;
                $xml .='     <lastname>'.$lastname.'</lastname>' ;
                $xml .='    <address>' ;
                $xml .='      <street>' .$street.'</street>' ;
                $xml .='      <zip>' . $zip.'</zip>' ;
                $xml .='      <city>'. $city .'</city>' ;
                $xml .='     <state>' . $state. '</state>' ;
                $xml .='    <country>'.$country. '</country>' ;
                $xml .='    </address>' ;
                $xml .='     <contact>' ;
                $xml .='     <email>'. $email.'</email>' ;
                // $xml .='     <phone>'. $phone.'</phone>' ;
                $xml .='   </contact>' ;
                $xml .='    <customer_ip>192.168.0.1</customer_ip>' ;
                $xml .='   <customer_id>1234567</customer_id>' ;
                $xml .='  </customer>' ;
                $xml .='    <custom1>...max 255 characters...</custom1>' ;
                $xml .='  <custom2>...max 255 characters...</custom2>' ;
                $xml .='   <custom3>...max 255 characters...</custom3>' ;
                $xml .='  </transaction>' ;
                $xml .='  <webgui>' ;
                $xml .='   <url_back_redirect_success>'. htmlspecialchars($url_back_redirect_success).'</url_back_redirect_success>' ;
                $xml .='    <url_back_redirect_failure>'. htmlspecialchars($url_back_redirect_success) .'</url_back_redirect_failure>' ;
                $xml .='     <url_status_notification>'. htmlspecialchars($url_back_redirect_success).'</url_status_notification>' ;
                $xml .='  </webgui>' ;
                $xml .='  </request_data>' ;
                $xml .=' </sspg_request>'; 
            $xml .=' </soap:Body>';
        $xml .=' </soap:Envelope>';

        return  $xml;
    }
    
    public function readXML($string){
        $response= array();
        $soap = simplexml_load_string($string); 
        $response["redirect_url"] =(string) $soap->children('http://schemas.xmlsoap.org/soap/envelope/')
                                                                ->Body->children()
                                                                ->sspg_response
                                                                ->response_data
                                                                ->status
                                                                ->wgp_status
                                                                ->sspg_redirect_url;
                                                                
        $response["status_code"] = (string)$soap->children('http://schemas.xmlsoap.org/soap/envelope/')
                                                                ->Body->children()
                                                                ->sspg_response
                                                                ->response_data
                                                                ->status
                                                                ->wgp_status
                                                                ->status_code;
        //$customerId = (string) $response->CreateRebillCustomerResult->RebillCustomerID;
        //echo $customerId;
                        
        return $response;
    }

    public function createStatusXmlParameter($merchant_id, $merchant_login,$tx_id, $tx_key) {
        $xml='<?xml version="1.0" encoding="UTF-8"?>
            <soap:Envelope xmlns:soap="http://schemas.xmlsoap.org/soap/envelope/" 
            xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" 
            xmlns:xsd="http://www.w3.org/2001/XMLSchema">
            <soap:Body>
            <sspg_request xmlns="http://sspg.payment-processor.de">
                <request_header>
                <merchant_id>'.$merchant_id . '</merchant_id>
                    <merchant_login>'. $merchant_login . '</merchant_login>
                <communication_id>UT154191086</communication_id>
                    <application_id>WWW1</application_id>
                    <sspg_interface>
                        <interface>BO</interface>
                    <version>1.0</version>
                    <request_type>STATUSCHECK</request_type>
                    <response_type>SYNC</response_type>
                </sspg_interface>
                </request_header>
                <request_data>
                    <transaction>
                        <sspg_reference>
                        <tx_id> '.$tx_id.'</tx_id>
                        <tx_key> '.$tx_key.' </tx_key>
                        <tx_type>AUTHORIZATION</tx_type>
                    </sspg_reference>
                    <order_id>OrderID-123</order_id>
                    <amount>1.23</amount>
                    <currency>KES</currency>
                    </transaction>
                </request_data></sspg_request>
            </soap:Body>
            </soap:Envelope>';
        
        return $xml;
    }

    public function readStatusXML($string){
        $response= array();
        $soap = simplexml_load_string($string); 
        
        $response["processing_status"] =(string) $soap->children('http://schemas.xmlsoap.org/soap/envelope/')
                                                                    ->Body->children()
                                                                    ->sspg_response
                                                                    ->response_data
                                                                    ->status
                                                                    ->processing_status;
                                                                
                                                                    
        $response["status_code"] = (string)$soap->children('http://schemas.xmlsoap.org/soap/envelope/')
                                                                    ->Body->children()
                                                                    ->sspg_response
                                                                    ->response_data
                                                                    ->status
                                                                    ->payment_status
                                                                    ->status_code;
        $response["status_description"] = (string)$soap->children('http://schemas.xmlsoap.org/soap/envelope/')
                                                                    ->Body->children()
                                                                    ->sspg_response
                                                                    ->response_data
                                                                    ->status
                                                                    ->payment_status
                                                                    ->status_description;
                                                                    
        $response["order_id"] = (string)$soap->children('http://schemas.xmlsoap.org/soap/envelope/')
                                                                    ->Body->children()
                                                                    ->sspg_response
                                                                    ->response_data
                                                                    ->order_id;															
        
        return $response;
    
    }

    public function processResponse($str) {
        $r= $this->readXML($str);
        if($r["status_code"] == "1363") {
            $url=$r["redirect_url"];
            header("Location: ".$url);
        }
    }

    public function redirectToCheckout($xml) {
        $url = "https://elivalat.com/evbridge/SSPG/post";

        $headers = array(
            "Content-type: text/xml",
            "Content-length: " . strlen($xml),
            "Connection: close",
        );

        $ch = curl_init(); 
        curl_setopt($ch, CURLOPT_URL, $url);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
        curl_setopt($ch, CURLOPT_TIMEOUT, 10);
        curl_setopt($ch, CURLOPT_POST, true);
        curl_setopt($ch, CURLOPT_POSTFIELDS, $xml);
        curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);  
        $response = curl_exec($ch); 

        $xml = simplexml_load_string($response);
        $this->processResponse($response); 

        if(curl_errno($ch)) {
            echo "ERROR   ".curl_error($ch);
        } else {
            curl_close($ch);
        }
    }

    public function processOrderCheckout($order, $currency) {
        $app = $this->application;
        $smarty = $this->smarty;
        $user = $app->container->user;
        $payload = Tools::getAllValues();
        
        if(ArrayUtils::has($payload, 'payNow')) {
            $redirectUri = $app->base_uri . '/dashboard/order/' . $order->id;

            $email = ArrayUtils::get($payload, 'email');
            $firstname = ArrayUtils::get($payload, 'firstname');
            $lastname = ArrayUtils::get($payload, 'lastname');
            $address = ArrayUtils::get($payload, 'address');
            $city = ArrayUtils::get($payload, 'city');
            $zipcode = ArrayUtils::get($payload, 'zipcode');
            $state = ArrayUtils::get($payload, 'state');
            $country = ArrayUtils::get($payload, 'country');
            
            $xml = $this->createXmlParameter(
                $order->id, 
                toFixed($order->total), 
                'USD', 
                $email, 
                $firstname, 
                $lastname,
                $address, 
                $zipcode, 
                $city, 
                $state, 
                $country,
                $app->base_uri . '/payment/'.$this->name.'/callback?handle=order&nodeId='.$order->id.'&redirectUri=' . $redirectUri,
                $app->base_uri . '/payment/'.$this->name.'/callback?handle=order&nodeId='.$order->id.'&redirectUri=' . $redirectUri,
                $app->base_uri . '/payment/'.$this->name.'/callback?handle=order&nodeId='.$order->id.'&redirectUri=' . $redirectUri
            );
    
            $this->redirectToCheckout($xml);
        } else {
            $smarty->assign('css_path', $this->local_path . 'views/_css.tpl');
            return $this->getTemplateContent('elivalatpay.pay');
        }
    }

    public function processPaperCheckout($paper, $currency) {
        $app = $this->application;
        $smarty = $this->smarty;
        $user = $app->container->user;
        $payload = Tools::getAllValues();

        if(ArrayUtils::has($payload, 'payNow')) {
            $redirectUri = $app->base_uri . '/dashboard/paper/' . $paper->id;

            $email = ArrayUtils::get($payload, 'email');
            $firstname = ArrayUtils::get($payload, 'firstname');
            $lastname = ArrayUtils::get($payload, 'lastname');
            $address = ArrayUtils::get($payload, 'address');
            $city = ArrayUtils::get($payload, 'city');
            $zipcode = ArrayUtils::get($payload, 'zipcode');
            $state = ArrayUtils::get($payload, 'state');
            $country = ArrayUtils::get($payload, 'country');

            $xml = $this->createXmlParameter(
                $paper->id, 
                toFixed($paper->total), 
                'USD', 
                $email, 
                $firstname, 
                $lastname,
                $address, 
                $zipcode, 
                $city, 
                $state, 
                $country,
                $app->base_uri . '/payment/'.$this->name.'/callback?handle=paper&nodeId='.$paper->id.'&redirectUri=' . $redirectUri,
                $app->base_uri . '/payment/'.$this->name.'/callback?handle=paper&nodeId='.$paper->id.'&redirectUri=' . $redirectUri,
                $app->base_uri . '/payment/'.$this->name.'/callback?handle=paper&nodeId='.$paper->id.'&redirectUri=' . $redirectUri
            );

            $this->redirectToCheckout($xml);
        } else {
            $smarty->assign('css_path', $this->local_path . 'views/_css.tpl');
            return $this->getTemplateContent('elivalatpay.pay');
        }
    }

    public function processAddPaymentCheckout($addPayment, $currency) {
        $app = $this->application;
        $smarty = $this->smarty;
        $user = $app->container->user;
        $payload = Tools::getAllValues();

        if(ArrayUtils::has($payload, 'payNow')) {
            $redirectUri = $app->base_uri . '/dashboard/add-payment/' . $addPayment->id;

            $email = ArrayUtils::get($payload, 'email');
            $firstname = ArrayUtils::get($payload, 'firstname');
            $lastname = ArrayUtils::get($payload, 'lastname');
            $address = ArrayUtils::get($payload, 'address');
            $city = ArrayUtils::get($payload, 'city');
            $zipcode = ArrayUtils::get($payload, 'zipcode');
            $state = ArrayUtils::get($payload, 'state');
            $country = ArrayUtils::get($payload, 'country');

            $xml = $this->createXmlParameter(
                $addPayment->id, 
                toFixed($addPayment->total), 
                'USD', 
                $email, 
                $firstname, 
                $lastname,
                $address, 
                $zipcode, 
                $city, 
                $state, 
                $country,
                $app->base_uri . '/payment/'.$this->name.'/callback?handle=add-payment&nodeId='.$addPayment->id.'&redirectUri=' . $redirectUri,
                $app->base_uri . '/payment/'.$this->name.'/callback?handle=add-payment&nodeId='.$addPayment->id.'&redirectUri=' . $redirectUri,
                $app->base_uri . '/payment/'.$this->name.'/callback?handle=add-payment&nodeId='.$addPayment->id.'&redirectUri=' . $redirectUri
            );

            $this->redirectToCheckout($xml);
        } else {
            $smarty->assign('css_path', $this->local_path . 'views/_css.tpl');
            return $this->getTemplateContent('elivalatpay.pay');
        }
    }

    public function processWalletCheckout($user_id, $amount, $currency) {
        $app = $this->application;
        $smarty = $this->smarty;
        $user = $app->container->user;
        $payload = Tools::getAllValues();

        if(ArrayUtils::has($payload, 'payNow')) {
            $redirectUri = $app->base_uri . '/dashboard/wallet';
            $amount = toFixed($amount);

            $email = ArrayUtils::get($payload, 'email');
            $firstname = ArrayUtils::get($payload, 'firstname');
            $lastname = ArrayUtils::get($payload, 'lastname');
            $address = ArrayUtils::get($payload, 'address');
            $city = ArrayUtils::get($payload, 'city');
            $zipcode = ArrayUtils::get($payload, 'zipcode');
            $state = ArrayUtils::get($payload, 'state');
            $country = ArrayUtils::get($payload, 'country');

            $xml = $this->createXmlParameter(
                $user_id, 
                $amount, 
                'USD', 
                $email, 
                $firstname, 
                $lastname,
                $address, 
                $zipcode, 
                $city, 
                $state, 
                $country,
                $app->base_uri . '/payment/'.$this->name.'/callback?handle=wallet&nodeId='.$user->id.'&amount='.$amount.'&redirectUri=' . $redirectUri,
                $app->base_uri . '/payment/'.$this->name.'/callback?handle=wallet&nodeId='.$user->id.'&amount='.$amount.'&redirectUri=' . $redirectUri,
                $app->base_uri . '/payment/'.$this->name.'/callback?handle=wallet&nodeId='.$user->id.'&amount='.$amount.'&redirectUri=' . $redirectUri
            );

            $this->redirectToCheckout($xml);
        } else {
            $smarty->assign('css_path', $this->local_path . 'views/_css.tpl');
            return $this->getTemplateContent('elivalatpay.pay');
        }
    }

    public function processTipCheckout($order_id, $amount, $currency) {
        $app = $this->application;
        $smarty = $this->smarty;
        $user = $app->container->user;
        $payload = Tools::getAllValues();

        if(ArrayUtils::has($payload, 'payNow')) {
            $redirectUri = $app->base_uri . '/dashboard/order/' . $order_id;
            $amount = toFixed($amount);

            $email = ArrayUtils::get($payload, 'email');
            $firstname = ArrayUtils::get($payload, 'firstname');
            $lastname = ArrayUtils::get($payload, 'lastname');
            $address = ArrayUtils::get($payload, 'address');
            $city = ArrayUtils::get($payload, 'city');
            $zipcode = ArrayUtils::get($payload, 'zipcode');
            $state = ArrayUtils::get($payload, 'state');
            $country = ArrayUtils::get($payload, 'country');

            $xml = $this->createXmlParameter(
                $order_id, 
                $amount, 
                'USD', 
                $email, 
                $firstname, 
                $lastname,
                $address, 
                $zipcode, 
                $city, 
                $state, 
                $country,
                $app->base_uri . '/payment/'.$this->name.'/callback?handle=tip&nodeId='.$order_id.'&amount='.$amount.'&redirectUri=' . $redirectUri,
                $app->base_uri . '/payment/'.$this->name.'/callback?handle=tip&nodeId='.$order_id.'&amount='.$amount.'&redirectUri=' . $redirectUri,
                $app->base_uri . '/payment/'.$this->name.'/callback?handle=tip&nodeId='.$order_id.'&amount='.$amount.'&redirectUri=' . $redirectUri
            );

            $this->redirectToCheckout($xml);
        } else {
            $smarty->assign('css_path', $this->local_path . 'views/_css.tpl');
            return $this->getTemplateContent('elivalatpay.pay');
        }
    } 

    /**
    * Hook action verify payment
    * @param $params array
    * @return void
    */
    public function verifyPaymentAfter($params) 
    { 
        $app = $this->application;
        $smarty = $this->smarty;
        $user = $app->container->user;

        if(ArrayUtils::has($params, 'handle')) {
            $handle = ArrayUtils::get($params, 'handle');
            $node_id = ArrayUtils::get($params, 'nodeId');
            $tx_id = ArrayUtils::get($params, 'tx_id');
            $tx_key = ArrayUtils::get($params, 'tx_key');
            $status_code = ArrayUtils::get($params, 'status_code');

            $merchant_id = Configuration::get(self::ELIVALATPAY_MERCHANT_ID);
            $merchant_login = Configuration::get(self::ELIVALATPAY_MERCHANT_LOGIN);
            $url = "https://elivalat.com/evbridge/SSPG/status";
        
            $xml= $this->createStatusXmlParameter($merchant_id, $merchant_login, $tx_id, $tx_key);

			$headers = array(
				"Content-type: text/xml",
				"Content-length: " . strlen($xml),
				"Connection: close",
			);

			$ch = curl_init(); 
			curl_setopt($ch, CURLOPT_URL,$url);
			curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
			curl_setopt($ch, CURLOPT_TIMEOUT, 10);
			curl_setopt($ch, CURLOPT_POST, true);
			curl_setopt($ch, CURLOPT_POSTFIELDS, $xml);
			curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);
			curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
			$response = curl_exec($ch); 
			
            $status = $this->readStatusXML($response);

            if( $status["status_code"] == "0" ) {
                $params['paymentId'] = $tx_id;
                $params['customer_id'] = $user->id;

                PaymentModule::processPayment( $node_id, $handle, $params );
                $smarty->assign(array(
                    'status' => 'success'
                ));
            } else {
                $smarty->assign(array(
                    'status' => 'error'
                ));
            }
        } else {
            $smarty->assign(array(
                'status' => 'error'
            ));
        }
    }
}