<?php
/**
 * @package    Proxim
 * @author     Davison Pro <davis@davisonpro.dev | https://davisonpro.dev>
 * @copyright  2019 Proxim
 * @version    1.5.0
 * @since      File available since Release 1.0.0
 */

use Proxim\Application;
use Proxim\Configuration;
use Proxim\Coupon;
use Proxim\Database\DbQuery;
use Proxim\Module\Module;
use Proxim\Order\Order;
use Proxim\User\Customer;
use Proxim\Util\ArrayUtils;
use Proxim\Validate;

class First_Order_Discount extends Module
{
    const FOD_DISCOUNT_PERCENTAGE = 'FOD_DISCOUNT_PERCENTAGE';
    const FOD_DEFAULT_DISCOUNT = 15;

    public function __construct()
    {
        $this->name = 'first_order_discount';
        $this->icon = 'fa fa-tag';
        $this->version = '1.0.0';
        $this->prox_versions_compliancy = array('min' => '1.0.0', 'max' => Application::VERSION);
        $this->author = 'Davison Pro';
        $this->displayName = 'First Order Discount';
        $this->description = 'Offer discounts to your customers on their first order with you.';

        $this->bootstrap = true;
        parent::__construct();
    }

    public function hookActionCustomerAccountAdd( $payload ) {
        $newCustomer = ArrayUtils::get($payload, 'newCustomer');

        $customer = new Customer( (int) $newCustomer->id );
        if(!Validate::isLoadedObject($customer)) {
            return false;
        }

        $coupon_expiry = date('Y-m-d H:i:s', strtotime('+1 month'));
        $coupon_discount = (float) Configuration::get(self::FOD_DISCOUNT_PERCENTAGE, PROX_ADMIN_SITE_ID, self::FOD_DEFAULT_DISCOUNT);

        $coupon = new Coupon();
        $coupon->site_id = $customer->site_id;
        $coupon->coupon_code = 'FD-' . $customer->id;
        $coupon->coupon_type = Coupon::PERCENT;
        $coupon->coupon_value = $coupon_discount;
        $coupon->expiry = $coupon_expiry;
        $coupon->user_id = $customer->id;
        $coupon->active = 1;
        $coupon->one_time = 1;
        $coupon->add();

        return true;
    }

    public function hookProcessPayment( $payload ) {
        $handle = ArrayUtils::get($payload, 'handle');
        $nodeId = ArrayUtils::get($payload, 'nodeId');

        switch($handle) {
            case 'order':
                $order = new Order( (int) $nodeId );
                if(Validate::isLoadedObject($order) && $order->coupon_id) {
                    $sql = new DbQuery();
                    $sql->select('coupon_id');
                    $sql->from('coupon', 'c');
                    $sql->where('coupon_id = ' . (int) $order->coupon_id );
                    $sql->where('user_id = ' . (int) $order->customer_id );
                    $sql->where('one_time = 1' );
                    $coupon = Db::getInstance()->getRow($sql);

                    if($coupon) {
                        Db::getInstance()->delete(
                            'coupon',
                            'coupon_id = ' . (int) $coupon['coupon_id']
                        );
                    }
                }
                break;
        }
    }

}